The VASP Calculator
--------------------

The Vienna Ab initio Simulation Package (VASP) is a program for atomic scale materials modelling from first principles.

The software is proprietary and therefore requires a license for use.

## Helpful links

 - [website](https://www.vasp.at/)
 - [documentation](https://www.vasp.at/wiki/index.php/The_VASP_Manual)
 - [tutorials](https://www.vasp.at/tutorials/latest/)
